@@ -64,6 +64,7 @@ namespace Ogre {
 
         int mLastViewportWidth, mLastViewportHeight;
         OrientationMode mLastViewportOrientationMode;
+        float mPixelRatio;
 
         bool parseChildren( DataStreamPtr& chunk, const String& line, int& l,
             Overlay* pOverlay, bool isTemplate, OverlayContainer* parent = NULL);
@@ -105,6 +106,8 @@ namespace Ogre {
         /// @copydoc ScriptLoader::getLoadingOrder
         Real getLoadingOrder(void) const;
 
+        void addOverlay(Overlay* overlay);
+
         /** Create a new Overlay. */
         Overlay* create(const String& name);
         /** Retrieve an Overlay by name 
@@ -133,6 +136,13 @@ namespace Ogre {
         /** Gets the orientation mode of the destination viewport. */
         OrientationMode getViewportOrientationMode(void) const;
 
+       /** Sets the pixel ratio: how many viewport pixels represent a single overlay pixel (in one dimension).
+
+       By default this is an 1:1 mapping. However on HiDPI screens you want to increase that to scale up your Overlay.
+       @see RenderWindow::getViewPointToPixelScale */
+       void setPixelRatio(float ratio);
+       float getPixelRatio() const;
+
         /** Creates a new OverlayElement of the type requested.
         @remarks
         The type of element to create is passed in as a string because this
